import React, { useState } from 'react';
import classNames from 'classnames';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faAngleDown, faCircleNotch } from '@fortawesome/free-solid-svg-icons';

/**
 *
 * @returns {Button}
 * @author Thushara Dinishka
 */

var Button = function Button(props) {
  var type = props.type,
      text = props.text,
      variant = props.variant,
      size = props.size,
      block = props.block;
  var classes = classNames("ark-btn", "ark-btn-" + variant, {
    "ark-btn-sm": size === "small",
    "ark-btn-lg": size === "large",
    "ark-btn-block": block
  });
  return React.createElement("button", {
    type: type,
    className: classes
  }, text);
};
Button.defaultProps = {
  type: "button",
  variant: "info",
  block: false
};

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

/**
 *
 * @returns {Checkbox}
 * @author Yazeer Ahamed
 */

var Checkbox = function Checkbox(_ref) {
  var label = _ref.label,
      name = _ref.name,
      props = _objectWithoutPropertiesLoose(_ref, ["label", "name"]);

  return React.createElement("div", {
    className: 'inline-flex items-center mt-3'
  }, React.createElement("input", Object.assign({
    type: "checkbox",
    name: name,
    className: "form-checkbox border-2  h-5 w-5 text-teal-500 border-teal-500 focus:outline-none"
  }, props)), React.createElement("span", {
    className: "ml-2 text-base font-normal text-gray-800"
  }, label));
};

/**
 *
 * @returns {Dropdown}
 * @author Yazeer Ahamed
 */

var Dropdown = function Dropdown(_ref) {
  var loading = _ref.loading,
      placeholder = _ref.placeholder,
      name = _ref.name,
      options = _ref.options,
      props = _objectWithoutPropertiesLoose(_ref, ["loading", "placeholder", "name", "options"]);

  var _useState = useState(true),
      notSelected = _useState[0],
      setSelected = _useState[1];

  var _useState2 = useState(0),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = useState(false),
      dropVisible = _useState3[0],
      setDropVisible = _useState3[1];

  var _useState4 = useState(''),
      text = _useState4[0],
      setText = _useState4[1];

  var displayOption = function displayOption() {
    if (loading) return React.createElement("span", {
      className: 'overflow-hidden text-gray-500 w-64 h-6 text-sm font-normal select-none cursor-pointer'
    }, "Loading");else if (notSelected) return React.createElement("span", {
      className: 'overflow-hidden text-gray-500 w-64 h-6 text-sm font-normal select-none cursor-pointer'
    }, placeholder);else return React.createElement("span", {
      className: 'overflow-hidden resize-none bg-gray-100 text-gray-800 w-64 h-6 text-sm font-normal select-none cursor-pointer'
    }, React.createElement("input", Object.assign({
      type: "number",
      hidden: true,
      value: value
    }, props)), text);
  };

  var handleDropDown = function handleDropDown() {
    setDropVisible(function (prevState) {
      return !prevState;
    });
  };

  var handleSelect = function handleSelect(option) {
    setText(option.label);
    setValue(option.id);
    setSelected(false);
    setDropVisible(false);
  };

  var dropOptions = options == null ? void 0 : options.map(function (option) {
    return React.createElement("span", {
      key: option.id,
      className: 'select-none cursor-pointer px-2 py-2 hover:bg-teal-300 rounded-md',
      onClick: function onClick() {
        handleSelect(option);
      }
    }, option.label);
  });
  return React.createElement(React.Fragment, null, React.createElement("div", {
    id: name,
    onClick: handleDropDown
  }, React.createElement("div", {
    className: "\n                bg-gray-100 rounded-md border-2 px-4 py-2 w-64 mt-2 space-x-4 flex justify-start cursor-pointer\n                " + (loading ? null : 'border-gray-500') + "\n                "
  }, displayOption(), React.createElement(FontAwesomeIcon, {
    className: 'font-normal',
    icon: faAngleDown
  }))), dropVisible && !loading ? React.createElement("div", {
    className: "flex flex-col mt-1 shadow-md absolute bg-gray-100 rounded-md w-64 \n                 " + (dropOptions.length > 5 ? 'h-56 overflow-y-scroll' : null)
  }, dropOptions) : null);
};

var LabelTypes;

(function (LabelTypes) {
  LabelTypes[LabelTypes["label"] = 0] = "label";
  LabelTypes[LabelTypes["success"] = 1] = "success";
  LabelTypes[LabelTypes["error"] = 2] = "error";
})(LabelTypes || (LabelTypes = {}));

var ButtonVariants;

(function (ButtonVariants) {
  ButtonVariants[ButtonVariants["info"] = 0] = "info";
  ButtonVariants[ButtonVariants["success"] = 1] = "success";
  ButtonVariants[ButtonVariants["danger"] = 2] = "danger";
})(ButtonVariants || (ButtonVariants = {}));

/**
 *
 * @returns {Label}
 * @author Thilina Rajapaksha
 */

var Label = function Label(props) {
  if (props.type === LabelTypes.label) {
    return React.createElement("label", {
      className: "text-gray-800 text-base font-medium select-none cursor-default tracking-wide",
      htmlFor: props.name
    }, props.label);
  } else if (props.type === LabelTypes.success) {
    return React.createElement("label", {
      className: "text-green-500 text-base font-medium select-none cursor-default tracking-wide ",
      htmlFor: props.name
    }, props.label);
  } else {
    return React.createElement("label", {
      className: "text-red-500 text-base font-medium select-none cursor-default tracking-wide ",
      htmlFor: props.name
    }, props.label);
  }
};

/**
 *
 * @returns {ProgressBar}
 * @author Thushara Dinishka
 */

var ProgressBar = function ProgressBar() {
  return React.createElement("div", {
    className: "w-full"
  }, React.createElement("div", {
    className: "w-full overflow-hidden"
  }, React.createElement("div", {
    className: "w-1/2 inline-block relative fluentProgressBar-waiting"
  })));
};

/**
 *
 * @returns {RadioButton}
 * @author Yazeer Ahamed
 */

var RadioButton = function RadioButton(_ref) {
  var label = _ref.label,
      name = _ref.name;
  return React.createElement("div", {
    className: 'inline-flex items-center mt-3'
  }, React.createElement("input", {
    type: "radio",
    name: name,
    className: "form-radio border-2  h-5 w-5 text-teal-500 bg-gray-300 focus:outline-none"
  }), React.createElement("span", {
    className: "ml-2 text-base font-normal text-gray-800"
  }, label));
};

/**
 *
 * @returns {Spinner}
 * @author Yazeer Ahamed
 */

var Spinner = function Spinner() {
  return React.createElement(React.Fragment, null, React.createElement("div", {
    className: "ark-info-spinner ease-linear rounded-full border-2 border-t-2 border-gray-300 h-4 w-4"
  }));
};

/**
 *
 * @returns {SubmitButton}
 * @author Thushara Dinishka
 */

var SubmitButton = function SubmitButton(props) {
  var isSubmitting = props.isSubmitting,
      text = props.text,
      variant = props.variant,
      size = props.size,
      block = props.block;
  var classes = classNames("ark-btn", "ark-btn-submit-" + variant, {
    "ark-btn-sm": size === "small",
    "ark-btn-lg": size === "large",
    "ark-btn-block": block
  });

  if (isSubmitting) {
    return React.createElement("button", {
      className: classes,
      type: "button"
    }, React.createElement(FontAwesomeIcon, {
      icon: faCircleNotch,
      className: "fa-spin"
    }), " Loading");
  } else {
    return React.createElement(Button, {
      text: text,
      type: "submit",
      variant: variant,
      size: size,
      block: block
    });
  }
};
SubmitButton.defaultProps = {
  variant: "info",
  block: false
};

/**
 *
 * @returns {TextField}
 * @author Thushara Dinishka
 */

var TextField = function TextField(_ref) {
  var type = _ref.type,
      placeholder = _ref.placeholder,
      size = _ref.size,
      disabled = _ref.disabled,
      props = _objectWithoutPropertiesLoose(_ref, ["type", "placeholder", "size", "disabled"]);

  var classes = classNames("ark-textfield", {
    "ark-textfield-lg": size === "large",
    "ark-textfield-sm": size === "small"
  });
  return React.createElement("input", Object.assign({
    type: type,
    placeholder: placeholder,
    disabled: disabled,
    className: classes
  }, props));
};
TextField.defaultProps = {
  type: "text",
  disabled: false
};

/**
 *
 * @returns {ToggleButton}
 * @author Yazeer Ahamed
 */

var ToggleButton = function ToggleButton(_ref) {
  var name = _ref.name,
      props = _objectWithoutPropertiesLoose(_ref, ["name"]);

  var _useState = useState(false),
      checked = _useState[0],
      setChecked = _useState[1];

  return React.createElement("div", {
    className: "relative rounded-full w-12 h-6 transition duration-200 ease-linear \n            " + (checked ? 'bg-green-500' : 'bg-gray-500') + "\n            "
  }, React.createElement("label", {
    className: "absolute left-0 bg-white border-2 mb-2 w-6 h-6 rounded-full transition transform duration-100 ease-linear\n            " + (checked ? 'translate-x-full border-green-500' : 'translate-x-0 border-gray-500') + "\n            "
  }, React.createElement("input", Object.assign({
    type: "checkbox",
    name: name
  }, props, {
    className: 'cursor-pointer appearance-none w-full h-full active:outline-none focus:outline-none',
    onClick: function onClick() {
      setChecked(function (prevState) {
        return !prevState;
      });
    }
  }))));
};

export { Button, ButtonVariants, Checkbox, Dropdown, Label, LabelTypes, ProgressBar, RadioButton, Spinner, SubmitButton, TextField, ToggleButton };
//# sourceMappingURL=arkstatic-components.esm.js.map
