import React, {FunctionComponent} from "react";
import classNames from "classnames";

/**
 *
 * @returns {Button Props}
 * @author Thushara Dinishka
 */
export interface ButtonProps {
    /**
     * The text content of the button.
     */
    text: string;
    /**
     * The type of the button.
     * Default type is `button`.
     */
    type?: "submit" | "reset" | "button";
    /**
     * The variant to use.
     * Default variant is `info`.
     */
    variant?: "info" | "success" | "danger" | "outline-info" | "outline-success" | "outline-danger";
    /**
     * The size of the button.
     * Default size is `normal`.
     */
    size?: "small" | "large" | "normal";
    /**
     * If `true` the button will span to the full width of its parent.
     */
    block?: boolean;
}

/**
 *
 * @returns {Button}
 * @author Thushara Dinishka
 */
export const Button: FunctionComponent<ButtonProps> = (props) => {

    const {type, text, variant, size, block} = props;

    const classes = classNames("ark-btn", `ark-btn-${variant}`, {
        "ark-btn-sm": size === "small",
        "ark-btn-lg": size === "large",
        "ark-btn-block": block
    });

    return (
        <button type={type} className={classes}>{text}</button>
    );
}

Button.defaultProps = {
    type: "button",
    variant: "info",
    block: false
}