import React, {FunctionComponent, useState} from "react";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faAngleDown} from "@fortawesome/free-solid-svg-icons";
import {DropdownOption} from "../util/DataVariants";


/**
 *
 * @returns {DropdownProps}
 * @author Yazeer Ahamed
 */

export interface DropdownProps {
    loading?: boolean
    placeholder: string
    name: string
    options: DropdownOption[]
    [key: string]: any
}

/**
 *
 * @returns {Dropdown}
 * @author Yazeer Ahamed
 */
export const Dropdown: FunctionComponent<DropdownProps> = ({loading, placeholder, name, options, ...props}) => {

    const [notSelected, setSelected] = useState(true)
    const [value, setValue] = useState(0)
    const [dropVisible, setDropVisible] = useState(false)
    const [text, setText] = useState('')

    const displayOption = () => {
        if (loading)
            return <span
                className='overflow-hidden text-gray-500 w-64 h-6 text-sm font-normal select-none cursor-pointer'>Loading</span>
        else if (notSelected)
            return <span
                className='overflow-hidden text-gray-500 w-64 h-6 text-sm font-normal select-none cursor-pointer'>{placeholder}</span>
        else
            return <span
                className='overflow-hidden resize-none bg-gray-100 text-gray-800 w-64 h-6 text-sm font-normal select-none cursor-pointer'
            >
                <input type="number" hidden={true} value={value} {...props}/>
                {text}
        </span>
    }

    const handleDropDown = () => {
        setDropVisible(prevState => !prevState)
    }

    const handleSelect = (option: DropdownOption) => {
        setText(option.label)
        setValue(option.id)
        setSelected(false)
        setDropVisible(false)
    }

    const dropOptions = options?.map(option => {
        return <span
            key={option.id}
            className='select-none cursor-pointer px-2 py-2 hover:bg-teal-300 rounded-md'
            onClick={() => {
                handleSelect(option)
            }}
        >{option.label}</span>
    })

    return (
        <React.Fragment>
            <div id={name} onClick={handleDropDown}>
                <div className={`
                bg-gray-100 rounded-md border-2 px-4 py-2 w-64 mt-2 space-x-4 flex justify-start cursor-pointer
                ${loading
                    ? null
                    : 'border-gray-500'
                }
                `}>
                    {displayOption()}
                    <FontAwesomeIcon className='font-normal' icon={faAngleDown}/>
                </div>
            </div>

            {dropVisible && !loading
                ? <div className={`flex flex-col mt-1 shadow-md absolute bg-gray-100 rounded-md w-64 
                 ${dropOptions.length > 5
                    ? 'h-56 overflow-y-scroll'
                    : null
                }`}>
                    {dropOptions}
                </div>
                : null
            }

        </React.Fragment>
    );
}
