import React, {FunctionComponent} from "react";
import {Button} from "./Button";
import {FontAwesomeIcon} from "@fortawesome/react-fontawesome";
import {faCircleNotch} from "@fortawesome/free-solid-svg-icons";
import classNames from "classnames";

/**
 *
 * @returns {SubmitButton Props}
 * @author Thushara Dinishka
 */
export interface SubmitButtonProps {
    /**
     * Whether the form is currently submitting.
     */
    isSubmitting: boolean;
    /**
     * The text content of the button.
     */
    text: string;
    /**
     * The variant to use.
     * Default variant is `info`.
     */
    variant?: "info" | "success" | "danger";
    /**
     * The size of the button.
     * Default size is `normal`.
     */
    size?: "small" | "large" | "normal";
    /**
     * If `true` the button will span to the full width of its parent.
     */
    block?: boolean;
}

/**
 *
 * @returns {SubmitButton}
 * @author Thushara Dinishka
 */
export const SubmitButton: FunctionComponent<SubmitButtonProps> = (props) => {

    const {isSubmitting, text, variant, size, block} = props;

    const classes = classNames("ark-btn", `ark-btn-submit-${variant}`, {
        "ark-btn-sm": size === "small",
        "ark-btn-lg": size === "large",
        "ark-btn-block": block
    });

    if (isSubmitting) {
        return (
            <button className={classes} type="button">
                <FontAwesomeIcon icon={faCircleNotch} className="fa-spin"/> Loading
            </button>
        );
    } else {
        return <Button text={text} type="submit" variant={variant} size={size} block={block}/>
    }
}

SubmitButton.defaultProps = {
    variant: "info",
    block: false
}
