import React, {FunctionComponent} from "react";
import classNames from "classnames";

/**
 *
 * @returns {TextField Props}
 * @author Thushara Dinishka
 */
export interface TextFieldProps {
    /**
     * The type of the textfield.
     * Default type is `text`.
     */
    type?: string;
    /**
     * The placeholder to display.
     */
    placeholder?: string;
    /**
     * The size of the textfield.
     * Default size is `normal`.
     */
    size?: "small" | "large" | "normal";
    /**
     * If `true` the textfield wouldn't be accessible.
     */
    disabled?: boolean;

    /**
     * Other additional props to pass.
     */
    [key: string]: any;
}

/**
 *
 * @returns {TextField}
 * @author Thushara Dinishka
 */
export const TextField: FunctionComponent<TextFieldProps> = ({type, placeholder, size, disabled, ...props}) => {

    const classes = classNames("ark-textfield", {
        "ark-textfield-lg": size === "large",
        "ark-textfield-sm": size === "small"
    });

    return (
        <input
            type={type}
            placeholder={placeholder}
            disabled={disabled}
            className={classes}
            {...props} />
    );
}

TextField.defaultProps = {
    type: "text",
    disabled: false
}