import React, {FunctionComponent, useState} from "react";

/**
 *
 * @returns {ToggleButtonProps}
 * @author Yazeer Ahamed
 */
export interface ToggleButtonProps {
    name: string
    [key: string]: any
}

/**
 *
 * @returns {ToggleButton}
 * @author Yazeer Ahamed
 */
export const ToggleButton: FunctionComponent<ToggleButtonProps> = ({name, ...props}) => {

    const [checked, setChecked] = useState(false)

    return (
        <div className={
            `relative rounded-full w-12 h-6 transition duration-200 ease-linear 
            ${checked
                ? 'bg-green-500'
                : 'bg-gray-500'
            }
            `
        }>
            <label className={`absolute left-0 bg-white border-2 mb-2 w-6 h-6 rounded-full transition transform duration-100 ease-linear
            ${checked
                ? 'translate-x-full border-green-500'
                : 'translate-x-0 border-gray-500'
            }
            `}>

                <input
                    type="checkbox"
                    name={name}
                    {...props}
                    className='cursor-pointer appearance-none w-full h-full active:outline-none focus:outline-none'
                    onClick={() => {
                        setChecked(prevState => !prevState)
                    }}
                />

            </label>

        </div>
    );
}
